MetadataExtractor class abstract

Implementers

Constructors

MetadataExtractor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractMetadataFromBytes(Uint8List bytes) Map<Frame, dynamic>
extractMetadataFromFile(File file) Future<Map<Frame, dynamic>>
extractMetadataFromPath(String path) Future<Map<Frame, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited